@@ -394,6 +394,11 @@ class CollectionItem(__Item):
         Return oplog
         """
         data = dict(self)
+
+        # Ensuring subcollections get added back
+        if self._subcollections:
+            data["/subcollections"] = self._subcollections
+
         doc, oplog = dict_mutator.mutate(mutations, data)
         row = self._collection.update_id(_id=self._id, doc=doc, replace=True, _as_document=False)
         self._load(row)
